<?php
/**
 * Copyright © 2016 Magento. All rights reserved.
 * See COPYING.txt for license details.
 */

namespace FiloBlu\Storelocator\Controller\PickUpInStore;

use \Magento\Framework\Exception\NotFoundException;

/**
 * Responsible for loading page content.
 *
 * This is a basic controller that only loads the corresponding layout file. It may duplicate other such
 * controllers, and thus it is considered tech debt. This code duplication will be resolved in future releases.
 */
class ConfirmReceived extends \Magento\Framework\App\Action\Action
{
    /** @var \Magento\Framework\View\Result\PageFactory */
    protected $resultPageFactory;

    /** @var \FiloBlu\Storelocator\Helper\Data */
    protected $helper;

    protected $_order;

    protected $_coreRegistry;

    public function __construct(
        \Magento\Framework\App\Action\Context $context,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory,
        \FiloBlu\Storelocator\Helper\Data $helper,
        \Magento\Sales\Api\Data\OrderInterface $order,
        \Magento\Framework\Registry $registry
    )
    {
        $this->resultPageFactory = $resultPageFactory;
        $this->helper = $helper;
        $this->_order = $order;
        $this->_coreRegistry = $registry;
        parent::__construct($context);
    }

    /**
     *
     * @return \Magento\Framework\View\Result\Page
     */
    public function execute()
    {
      $params = $this->getRequest()->getParams();

      if (!$this->helper->getConfig('carriers/pickup_in_store/active') || !isset($params["increment_id"]) || !$params["increment_id"] || !isset($params["hash"]) || !$params["hash"]) {
          return $this->_forward('noRoute');
      }

      $this->_order->loadByIncrementId($params["increment_id"]);

      if ($this->_order->getId() && $this->_order->getPickupInStoreHash() == $params["hash"] && $this->_order->getShippingMethod() == "pickup_in_store_pickup_in_store") {
        $this->_coreRegistry->register('pickupinstore_order_confirm_received',$this->_order);
        $resultPage = $this->resultPageFactory->create();
        $resultPage->getConfig()->getTitle()->set("PickUp In Store - Confirmation of receipt of the package for order " . $params["increment_id"]);

        return $resultPage;
      }
      else {
        return $this->_forward('noRoute');
      }
    }
}
